from setuptools import setup, find_packages

# Leer el contenido del archiov README.# 
with open("README.md","r",encoding="utf-8") as fh:
    long_description=fh.read()

setup(
        name="hack4u-jpcozar",
        version="0.6.0",
        packages=find_packages(),
        install_requires=[],
        author="Javier Polo",
        description="Una biblioteca para consultar cursos de hack4u",
        long_description=long_description,
        long_description_content_type="text/markdown",
        url="https://hack4u.io",
        )        





class Course:
    def __init__(self,name,duration,link):
        self.name=name
        self.duration=duration
        self.link=link

    def __repr__(self):
        return f"{self.name} [{self.duration} horas] ({self.link})"


courses = [
    Course("Introducción a Linux",15,"https://hack4u.io/cursos/introduccion-a-linux/"),
    Course("Personalización de Linux",3,"https://hack4u.io/cursos/personalizacion-de-entorno-en-linux/"),
    Course("Introducción al Hacking",53,"https://hack4u.io/cursos/introduccion-al-hacking/"),
        ]

def list_courses():
    for course in courses:
        print(course)

def search_course_by_name(name):
    for course in courses:
        if course.name == name:
            return course

    return None

